@@ -21,12 +21,14 @@ from .functions_projects import (
     )
 from .functions import (
     load_file,
+    get_running_backend_version,
     )
 from .functions_components import (
     get_tags_from_string,
     comp_create,
     export_components,
-    get_comp_statistics
+    get_comp_statistics,
+    split_uid,
     )
 
 # deprecated functions
