@@ -45,3 +45,22 @@ def get_comp_statistics() -> dict:
     status_code, response = _backend_GET(endpoint="/v2/streamlit/db/stats/components")
     return response
 
+
+def split_uid(uid: str) -> tuple[str, str, str, int | str]:
+    """Splits a component UID into its constituent parts: type, subtype, and name.
+
+    Args:
+        uid (str): The UID of the component in the format 'type-subtype-name'.
+
+    Returns:
+        tuple: A tuple containing the type, subtype, and name of the component.
+    """
+    try:
+        system_uid, subsystem_uid, component_class, component_id = uid.split("_", 3)
+        try:
+            component_id = int(component_id)
+        except ValueError:
+            pass
+        return system_uid, subsystem_uid, component_class, component_id
+    except ValueError:
+        raise ValueError("Invalid UID format. Expected UID format: <system>_<subsystem>_<component_class>_<component_id>")
\ No newline at end of file
